@@ -162,7 +162,7 @@ def batch_create_data_rows(client, dataset, global_key_to_upload_dict, skip_dupl
         skip_duplicates             : Optional (bool) - If True, will skip duplicate global_keys, otherwise will generate a unique global_key with a suffix "_1", "_2" and so on
         batch_size                  : Optional (int) : Upload batch size, 20,000 is recommended
     Returns:
-        A concatenated list of upload results for all batch uploads
+        Upload errors - returns False if no errors
     """
     def __check_global_keys(client, global_keys):
         """ Checks if data rows exist for a set of global keys
@@ -190,13 +190,13 @@ def batch_create_data_rows(client, dataset, global_key_to_upload_dict, skip_dupl
             if payload['deletedDataRowGlobalKeys']:
                 client.clear_global_keys(payload['deletedDataRowGlobalKeys'])
                 payload = __check_global_keys(client, global_keys_list)
-                continue
-            # If gloval keys are taken by existing data rows, either skip them on upload or update the global key to have a "_{loop_counter}" suffix
+            # If global keys are taken by existing data rows, either skip them on upload or update the global key to have a "_{loop_counter}" suffix
             if payload['fetchedDataRows']:
                 loop_counter += 1
                 for i in range(0, len(payload['fetchedDataRows'])):
                     current_global_key = str(global_keys_list[i])
                     new_global_key = f"{current_global_key[:-3]}__{loop_counter}" if current_global_key[-3:-1] == "__" else f"{current_global_key}__{loop_counter}"
+                    print(new_global_key)
                     if payload['fetchedDataRows'][i] != "":
                         if skip_duplicates:
                             del global_key_to_upload_dict[current_global_key] # Delete this data_row_upload_dict from your upload_dict
@@ -208,16 +208,18 @@ def batch_create_data_rows(client, dataset, global_key_to_upload_dict, skip_dupl
                 global_keys_list = list(global_key_to_upload_dict.keys())
                 payload = __check_global_keys(client, global_keys_list)
     upload_list = list(global_key_to_upload_dict.values())
-    upload_results = []
     for i in range(0,len(upload_list),batch_size):
         batch = upload_list[i:] if i + batch_size >= len(upload_list) else upload_list[i:i+batch_size]
         task = dataset.create_data_rows(batch)
         task.wait_till_done()
-        if task.errors:
-            print(f'Data Row Creation Error: {task.errors}')
-            return task.errors
-    return upload_results
-
+        errors = task.errors
+        if errors:
+            if type(errors) == str:
+                print(f'Data Row Creation Error: {errors}')
+            else:
+                print(f'Data Row Creation Error: {errors[0]}')
+            return errors
+    return False
 
 def upsert_function(upsert_dict_bytes, global_key_col, metadata_value_col):
     """ Nested UDF Functionality upsert metadata in Labelbox and in the pyspark dataframe
